MatchPage

Struct MatchPage 

pub struct MatchPage {
    pub id: u32,
    pub status: MatchStatus,
    pub team1: Option<Team>,
    pub team2: Option<Team>,
    pub event: Event,
    pub date: DateTime<Utc>,
    pub format: MatchFormat,
    pub score: Option<MatchScore>,
    pub maps: Vec<MapScore>,
    pub stats: Vec<Performance>,
}
Contains detailed information about a match. Corresponds to data found on HLTV’s match page.

Fields

id: u32

ID of the match

status: MatchStatus

Status of the match.

team1: Option<Team>

First team, if known.

team2: Option<Team>

Second team, if known.

event: Event

Event at which this match is played.

date: DateTime<Utc>

Time when a match is supposed to start. This is different from the timestamp found on MatchResult (which is the time the match result was published).

format: MatchFormat

Format of the match. The format determines how many maps a team needs to win a match.

score: Option<MatchScore>

A match score. In case of bo1, either 1-0 or 0-1. For bo3 it’s 2-0, 2-1 and so on.

maps: Vec<MapScore>

A collection of map-specific scores. Up to 7 maps can be played per map. Empty if the game hasn’t started yet. Contains partial results if maps have been played but the match hasn’t fully concluded yet (which can be the case for bo3+).

stats: Vec<Performance>

Performance of players over all maps.